Reference &mdash; Transmogrify v0.1beta2 documentation

# Reference #
## Settings ##
* TRANSMOGRIFY_SECRET
* TRANSMOGRIFY_DEBUG
* TRANSMOGRIFY_BASE_PATH
* TRANSMOGRIFY_PATH_ALIASES
* TRANSMOGRIFY_USE_VHOSTS
* TRANSMOGRIFY_VHOST_DOC_BASE
* TRANSMOGRIFY_NO_IMG_URL
